# django-riometrics-middleware

Django middleware to collect HTTP metrics.

## Installation

``pip install django-riometrics-middleware==1.1.0``

## Usage

Just add ``rio_metrics.middleware.HTTPMetricsMiddleware`` to your middleware.